@@ -16,7 +16,7 @@ use constant INFINITY     =>       100 ** 100 ** 100 ;
 use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
 
 BEGIN {
-    $VERSION = '0.1411';
+    $VERSION = '0.1412';
 }
 
 sub iterate {
@@ -114,6 +114,9 @@ sub from_recurrence {
     $param{next} = delete $args{recurrence}  or
     $param{next} = delete $args{next};
     $param{previous} = $args{previous}  and  delete $args{previous};
+
+    $param{detect_bounded} = delete $args{detect_bounded} or 0;
+
     $param{span} = $args{span}  and  delete $args{span};
     # they might be specifying a span using begin / end
     $param{span} = DateTime::Span->new( %args ) if keys %args;
@@ -196,10 +199,19 @@ sub from_recurrence {
                 }
         }
 
-        my $max = $param{previous}->( DateTime::Infinite::Future->new );
-        my $min = $param{next}->( DateTime::Infinite::Past->new );
-        $max = INFINITY if $max->is_infinite;
-        $min = NEG_INFINITY if $min->is_infinite;
+        my ( $min, $max );
+        if ( $param{detect_bounded} )
+        {
+            $max = $param{previous}->( DateTime::Infinite::Future->new );
+            $min = $param{next}->( DateTime::Infinite::Past->new );
+            $max = INFINITY if $max->is_infinite;
+            $min = NEG_INFINITY if $min->is_infinite;
+        }
+        else
+        {
+            $max = INFINITY;
+            $min = NEG_INFINITY;
+        }
         my $base_set = Set::Infinite::_recurrence->new( $min, $max );
         $base_set = $base_set->intersection( $param{span}->{set} )
              if $param{span};
@@ -736,7 +748,8 @@ It is also possible to create a recurrence by specifying either or both
 
 Callbacks can return C<DateTime::Infinite::Future> and 
 C<DateTime::Infinite::Past> objects, in order to define I<bounded recurrences>.
-In this case, both 'next' and 'previous' callbacks must be defined:
+In this case, both 'next' and 'previous' callbacks must be defined,
+and the "detect_bounded" switch must be used:
 
     # "monthly from $dt until forever"
 
@@ -754,6 +767,7 @@ In this case, both 'next' and 'previous' callbacks must be defined:
             return $_[0] if $_[0] >= $dt;
             return DateTime::Infinite::Past->new;
         },
+        detect_bounded => 1,
     );
 
 Bounded recurrences are is easier to write using span parameters:
